@@ -2,6 +2,7 @@
 // defines household behavior in world
 
 #import "Agent.h"
+#import <random.h>
 
 // birth and death global
 #define STATE_GOOD 0.05
@@ -41,11 +42,13 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   return self;
 }
 
--setWorld: (id) w {
+-setWorld: (id <Grid2d>)w 
+{
   world = w;
   // cache locally the world size for later use
   worldX = [world getSizeX];
   worldY = [world getSizeY];
+
   return self;
 }
 
@@ -86,7 +89,7 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   agent_time = 0;
   
   // initial planting habits and cal needs
-  state = 2;
+  agentState = 2;
   maize_storage = 450 * num_family;		  // initial endowment in kg
   max_store = 450 * num_family;
   EXP_cal_need = [self calcExpCalUse];
@@ -162,17 +165,17 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 
   // act the season, a whole year each step
   [self spring];
-  if (state > -1) [self summer];
-  if (state > -1) [self fall];
-  if (state > -1) [self winter];
+  if (agentState > -1) [self summer];
+  if (agentState > -1) [self fall];
+  if (agentState > -1) [self winter];
   maize_storage -= (int) (STORAGE_DECR*maize_storage);
   
   // calculate annual birth
-  if (state > -1) [self birth: ages[0]];          // mother is ages[0]
-  if (state > -1) [self updateFamily];            // execute family happenings
-  if (state > -1) [self evalState];               // how am I doing
+  if (agentState > -1) [self birth: ages[0]];          // mother is ages[0]
+  if (agentState > -1) [self updateFamily];            // execute family happenings
+  if (agentState > -1) [self evalState];               // how am I doing
   
-  if (state == -1 && num_family != 0){
+  if (agentState == -1 && num_family != 0){
     fprintf(stderr,"ERROR: agent %d ending with bad fam size %d\n",
             tag,num_family); exit(-1);
   }         
@@ -383,9 +386,9 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   float tmp=1.0;
   int index;
   // checks state, alters percentage from that
-  if (state<1)
+  if (agentState<1)
     tmp += STATE_BAD;
-  if (state>2)
+  if (agentState>2)
     tmp += STATE_GOOD;
 
   if (14 < m_age && m_age < 50 && num_kids < 8){
@@ -405,9 +408,9 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   // check to see if person dies randomly (within age group)
   // this is the modifed version which depends on the state of the household
   float tmp=1.0;
-  if (state<1)
+  if (agentState<1)
     tmp -= STATE_BAD;
-  if (state>2)
+  if (agentState>2)
     tmp -= STATE_GOOD;
 
   if (age<1)
@@ -428,8 +431,8 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 
 -death
 {
-  if (state != -1){
-    state = -1;
+  if (agentState != -1){
+    agentState = -1;
     [self unPlotAll];
     [cell[4] removeSettler: self];
     //    [self clearSettler];
@@ -478,22 +481,22 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   EXP_cal_need = total_cal+EXP_cal_need/2;        
 
   // calculate internal state
-  state = 0;
-  state += ([traders getBalance] > 0) ? 1:0;
+  agentState = 0;
+  agentState += ([traders getBalance] > 0) ? 1:0;
 // what is the /2 for ???
-  state += (maize_storage*MAIZE_KG_CAL > (int)(MAIZE_PER*EXP_cal_need)/2)? 1:0;
-  state += (AVG_cal_prod  > MAIZE_PER*EXP_cal_need)?1:0;
+  agentState += (maize_storage*MAIZE_KG_CAL > (int)(MAIZE_PER*EXP_cal_need)/2)? 1:0;
+  agentState += (AVG_cal_prod  > MAIZE_PER*EXP_cal_need)?1:0;
   
-  if (state == 3){
+  if (agentState == 3){
     if (plot_need > 0 || tot_plots == 0)
       plot_need = 0;
     if (tot_plots > 0)
       plot_need--;
-  } else if (state == 2){ // they are happy ! just right
+  } else if (agentState == 2){ // they are happy ! just right
     plot_need = 0;
-  } else if (state == 1){
+  } else if (agentState == 1){
     if (maize_storage < max_store) plot_need++;
-  } else if (state == 0){
+  } else if (agentState == 0){
     [self moveHouse];
   }
 
@@ -666,7 +669,7 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
   [self setX: wrapX(dx) Y: wrapY(dy)];
   if (DEBUG == 1 && tag == TAG)
     printf("DEBUG: agent %d moving to (%d,%d)\n",tag,x,y);
-  state = 1;
+  agentState = 1;
   plot_need = 2 + num_kids / 2;
   return self;
 }
@@ -695,7 +698,7 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 {
   int i,j,k,n,n1,n2,t,max;
   int dx,dy;
-  static order[4] = {0,1,2,3};
+  static int order[4] = {0,1,2,3};
   k = max = 0;
   for (i=1;i<=radius;i++){
     // make sure search directions are randomized
@@ -796,8 +799,9 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 }
 
 
--(int) getState {
-  return (state);
+-(int) getAgentState
+{
+  return (agentState);
 }
 
 -(int) getMaxStore{
@@ -807,12 +811,14 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 // Extra bits of display code: setting our colour, drawing on a window.
 // This code works, but it'd be better if there were a generic object
 // that knew how to draw agents on grids.
--setColor: (Color) c {
+- setColor: (Color)c
+{
   myColor = c;
   return self;
 }
 
--drawSelfOn: (Raster *) r {
+- drawSelfOn: (id <Raster>) r
+{
   [r drawPointX: x Y: y Color: myColor];
   return self;
 }
@@ -821,7 +827,8 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
 // debugging stuff
 
 // agent debugging, print out internal state
--debug: (int) key {
+- debug: (int)key
+{
   // if key is -1, automatically print out own internal state
   if ( tag==key || key ==-1 ) {
     int i,j;
@@ -829,7 +836,7 @@ static float death_per[15] = {.2330,.1400,.1000,.0735,.1305,.1336,.1367,.1400,
     // print general info about the cell occupied and household state
     printf("DEBUG:  AGENT %d\n",tag);
     printf("\tinfo:\tlocation (%d,%d) state %d plot_need %d\n",
-           x,y,state,plot_need);
+           x,y,agentState,plot_need);
     printf("\thist:\tformation %d agentTime %d\n",form_date,agent_time);
 
     // print out the ages
