@@ -1,7 +1,7 @@
 // AgentModelSwarm.h
 // swarm room 1996
 
-#import <swarmobject.h>
+#import <objectbase/Swarm.h>
 #import <space.h>
 #import <activity.h>
 #import <collections.h>
@@ -12,7 +12,7 @@
 #import "DataBase.h"
 
 // the swarm
-@interface AgentModelSwarm : Swarm
+@interface AgentModelSwarm: Swarm
 {
   int allAgents;				  // total num agents overall
   int which_yield;
@@ -27,29 +27,29 @@
   id agentList;					  // set of players
   id cellList;					  // set of cells in grid2d
   id database;
-  Grid2d * world;
+  id <Grid2d> world;
 }
 
 // creation stuff
-+createBegin: (id) aZone;                         // extra methods you
--createEnd;                                       // provide for Swarms
--buildObjects;
--initWorld;
--initDataBase;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;                             // extra methods you
+- createEnd;                                      // provide for Swarms
+- buildObjects;
+- initWorld;
+- initDataBase;
+- buildActions;
+- activateIn: swarmContext;
 
 // get structures
--getAgentList;                                  // access methods into the
--getCellList;
--(Grid2d *) getWorld;                             // model swarm. These methods
--(int) getNumAgents;
--(int) getEstAgents;
+- getAgentList;                                  // access methods into the
+- getCellList;
+- (id <Grid2d>)getWorld;                         // model swarm. These methods
+- (int)getNumAgents;
+- (int)getEstAgents;
 
 // agent additon
--addRandomAgents: (int) num;
--addAgentX: (int) newx Y: (int) newy;
--removeAgents;
--debug;
+- addRandomAgents: (int)num;
+- addAgentX: (int)newx Y: (int)newy;
+- removeAgents;
+- debug;
 
 @end
