@@ -231,8 +231,9 @@
   return world;
 }
 
--(int) getNumAgents {
-  return [agentList count];
+- (int)getNumAgents
+{
+  return [agentList getCount];
 }
 
 -(int) getEstAgents {
@@ -289,7 +290,8 @@
   return self;
 }
 
--removeAgents {
+- removeAgents 
+{
   id index,t;
 
   index = [agentList begin: [self getZone]];
@@ -299,7 +301,7 @@
   }
   [index drop];
 
-  printf("REMOVE: num of agents %d total %d\n",[agentList count],allAgents);
+  printf("REMOVE: num of agents %d total %d\n",[agentList getCount],allAgents);
 
   return self;
 }
