@@ -166,7 +166,7 @@
 
 - (int)getNumHouses
 {
-  return ([settlerSet count]);
+  return ([settlerSet getCount]);
 }
 
 
@@ -240,7 +240,7 @@
   if ((x == inx && y == iny) || inx == -1 )
     {
       printf("x: %d y: %d settlers: %d planted: %d\n",
-             x,y,[settlerSet count],farming_plots);
+             x,y,[settlerSet getCount],farming_plots);
     }
   return self;
 }
